![Image about SiDoLa Nervous Sytem Concept](Figure1.png)
# SiDoLa-NS
SiDoLa (prounounced like Do Re Mi) is short for "Simulate Don't Label". These are a set of tools to create nervous system simulations and used the resulting models to extract image-based features from biological sections of nervous system tissue.

## Citation
BioArxiv coming soon

## Getting started
Open the "SiDoLa-NS Training and Inference.ipynb" file for more information and instructions.

## Authors and acknowledgment
William Buchser and Lina Mohammed Ali

## License
AGPL3.0